aboutsummaryrefslogtreecommitdiffstats
path: root/aai-core
diff options
context:
space:
mode:
authorasgar <sammoham@in.ibm.com>2018-09-11 14:08:43 +0530
committerasgar <sammoham@in.ibm.com>2018-09-11 14:08:49 +0530
commit3aa58f7244c6123972cd98851a3e9dcd6652d75a (patch)
tree22b2e5b072e34fc66dd79b422cffb47b565b2fc8 /aai-core
parent922990e4abebf878de7eaf7ee3a7de48c22ced0d (diff)
Add a private constructor in AAIUtils.java
Change-Id: I7a2beeede4cb8303b7f9801532a651895cbce389 Issue-ID: AAI-1566 Signed-off-by: Mohamed Asgar Samiulla <sammoham@in.ibm.com>
Diffstat (limited to 'aai-core')
-rw-r--r--aai-core/src/main/java/org/onap/aai/util/AAIUtils.java51
1 files changed, 30 insertions, 21 deletions
diff --git a/aai-core/src/main/java/org/onap/aai/util/AAIUtils.java b/aai-core/src/main/java/org/onap/aai/util/AAIUtils.java
index ce53d86e..ba2cf9e2 100644
--- a/aai-core/src/main/java/org/onap/aai/util/AAIUtils.java
+++ b/aai-core/src/main/java/org/onap/aai/util/AAIUtils.java
@@ -4,6 +4,8 @@
* ================================================================================
* Copyright © 2017-2018 AT&T Intellectual Property. All rights reserved.
* ================================================================================
+ * Modifications Copyright © 2018 IBM.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
@@ -26,27 +28,34 @@ import java.util.Date;
import java.util.TimeZone;
public class AAIUtils {
+
+ /**
+ * Instantiates AAIUtils.
+ */
+ private AAIUtils() {
+ // prevent instantiation
+ }
- /**
- * Null check.
- *
- * @param <T> the generic type
- * @param iterable the iterable
- * @return the iterable
- */
- public static <T> Iterable<T> nullCheck(Iterable<T> iterable) {
- return iterable == null ? Collections.<T>emptyList() : iterable;
- }
+ /**
+ * Null check.
+ *
+ * @param <T> the generic type
+ * @param iterable the iterable
+ * @return the iterable
+ */
+ public static <T> Iterable<T> nullCheck(Iterable<T> iterable) {
+ return iterable == null ? Collections.<T>emptyList() : iterable;
+ }
- /**
- * Gen date.
- *
- * @return the string
- */
- public static String genDate() {
- Date date = new Date();
- DateFormat formatter = new SimpleDateFormat("YYMMdd-HH:mm:ss:SSS");
- formatter.setTimeZone(TimeZone.getTimeZone("GMT"));
- return formatter.format(date);
- }
+ /**
+ * Gen date.
+ *
+ * @return the string
+ */
+ public static String genDate() {
+ Date date = new Date();
+ DateFormat formatter = new SimpleDateFormat("YYMMdd-HH:mm:ss:SSS");
+ formatter.setTimeZone(TimeZone.getTimeZone("GMT"));
+ return formatter.format(date);
+ }
}